@@ -117,8 +117,7 @@ class NLPDataset:
             dataset = dataset.map(after_batch)
         return dataset.prefetch(buffer_size=tf.data.experimental.AUTOTUNE)
 
-    def dataframe_to_dataset(self, df: pd.DataFrame, na_value: str) -> tf.data.Dataset:
-        df.fillna(na_value, inplace=True)
+    def dataframe_to_dataset(self, df: pd.DataFrame) -> tf.data.Dataset:
         return tf.data.Dataset.from_tensor_slices(tuple(df[col] for col in df.columns))
 
     def load_csv(
@@ -131,9 +130,10 @@ class NLPDataset:
     ) -> Tuple[tf.data.Dataset, Optional[int]]:
         if in_memory:
             df = pd.read_csv(filename, sep=sep, quoting=3)
+            df.fillna(na_value, inplace=True)
             for dtype, col in zip(column_dtypes, df.columns):
                 df[col] = df[col].astype(dtype)
-            return self.dataframe_to_dataset(df, na_value), df.shape[0]
+            return self.dataframe_to_dataset(df), df.shape[0]
         tf_dtype_mapping = {"str": tf.string, "int": tf.int32, "float": tf.float32}
         return (
             tf.data.experimental.CsvDataset(
