@@ -1,5 +1,5 @@
-from typing import Sequence, Optional, Union, Any, Dict
-import functools
+from __future__ import annotations
+from typing import Optional, Any
 
 import tensorflow as tf
 from tensorflow.keras.metrics import Precision, Recall
@@ -9,25 +9,21 @@ from tensorflow_addons.metrics import FBetaScore
 class PrecisionWithLogits(Precision):
     def __init__(
         self,
-        thresholds: Union[float, Sequence[float], None] = None,
         top_k: Optional[int] = None,
         class_id: Optional[int] = None,
+        threshold: float = 0.5,
         name: str = "precision",
         dtype: Optional[tf.DType] = None,
-        logits2scores: str = "sigmoid",
+        activation: str = "linear",
     ) -> None:
         super().__init__(
-            thresholds=thresholds,
+            thresholds=threshold,
             top_k=top_k,
             class_id=class_id,
             name=name,
             dtype=dtype,
         )
-        self.logits2scores = logits2scores
-        if logits2scores == "sigmoid":
-            self._l2s = tf.math.sigmoid
-        elif logits2scores == "softmax":
-            self._l2s = functools.partial(tf.math.softmax, axis=-1)
+        self.activation = activation
 
     def update_state(
         self,
@@ -35,34 +31,37 @@ class PrecisionWithLogits(Precision):
         y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
-        super().update_state(y_true, self._l2s(y_logits), sample_weight=sample_weight)
+        y_pred = tf.keras.activations.deserialize(self.activation)(y_logits)
+        super().update_state(y_true, y_pred, sample_weight=sample_weight)
 
-    def get_config(self) -> Dict[str, Any]:
-        return {**super().get_config(), "logits2scores": self.logits2scores}
+    def get_config(self) -> dict[str, Any]:
+        configs = super().get_config()
+        configs.pop("thresholds", None)
+        return {
+            **configs,
+            "threshold": self.thresholds,
+            "activation": self.activation,
+        }
 
 
 class RecallWithLogits(Recall):
     def __init__(
         self,
-        thresholds: Union[float, Sequence[float], None] = None,
         top_k: Optional[int] = None,
         class_id: Optional[int] = None,
+        threshold: float = 0.5,
         name: str = "recall",
         dtype: Optional[tf.DType] = None,
-        logits2scores: str = "sigmoid",
+        activation: str = "linear",
     ) -> None:
         super().__init__(
-            thresholds=thresholds,
+            thresholds=threshold,
             top_k=top_k,
             class_id=class_id,
             name=name,
             dtype=dtype,
         )
-        self.logits2scores = logits2scores
-        if logits2scores == "sigmoid":
-            self._l2s = tf.math.sigmoid
-        elif logits2scores == "softmax":
-            self._l2s = functools.partial(tf.math.softmax, axis=-1)
+        self.activation = activation
 
     def update_state(
         self,
@@ -70,10 +69,17 @@ class RecallWithLogits(Recall):
         y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
-        super().update_state(y_true, self._l2s(y_logits), sample_weight=sample_weight)
+        y_pred = tf.keras.activations.deserialize(self.activation)(y_logits)
+        super().update_state(y_true, y_pred, sample_weight=sample_weight)
 
-    def get_config(self) -> Dict[str, Any]:
-        return {**super().get_config(), "logits2scores": self.logits2scores}
+    def get_config(self) -> dict[str, Any]:
+        configs = super().get_config()
+        configs.pop("thresholds", None)
+        return {
+            **configs,
+            "threshold": self.thresholds,
+            "activation": self.activation,
+        }
 
 
 class FBetaScoreWithLogits(FBetaScore):
@@ -82,24 +88,20 @@ class FBetaScoreWithLogits(FBetaScore):
         num_classes: int,
         average: str = "micro",
         beta: float = 1.0,
-        thresholds: float = 0.5,
+        threshold: float = 0.5,
         name: str = "fbeta_score",
         dtype: Optional[tf.DType] = None,
-        logits2scores: str = "sigmoid",
+        activation: str = "linear",
     ) -> None:
         super().__init__(
             num_classes,
             average=average,
             beta=beta,
-            threshold=thresholds,
+            threshold=threshold,
             name=name,
             dtype=dtype,
         )
-        self.logits2scores = logits2scores
-        if logits2scores == "sigmoid":
-            self._l2s = tf.math.sigmoid
-        elif logits2scores == "softmax":
-            self._l2s = functools.partial(tf.math.softmax, axis=-1)
+        self.activation = activation
 
     def update_state(
         self,
@@ -107,13 +109,11 @@ class FBetaScoreWithLogits(FBetaScore):
         y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
-        super().update_state(y_true, self._l2s(y_logits), sample_weight=sample_weight)
+        y_pred = tf.keras.activations.deserialize(self.activation)(y_logits)
+        super().update_state(y_true, y_pred, sample_weight=sample_weight)
 
-    def get_config(self) -> Dict[str, Any]:
-        configs = super().get_config()
-        configs.pop("threshold", None)
+    def get_config(self) -> dict[str, Any]:
         return {
-            **configs,
-            "logits2scores": self.logits2scores,
-            "thresholds": self.threshold,
+            **super().get_config(),
+            "activation": self.activation,
         }
\ No newline at end of file
