@@ -14,6 +14,7 @@ class TextRNNTagger(DeepTagger):
         sequence_length: int = None,
         segmenter: str = "char",
         embedding_size: int = 100,
+        use_batch_normalization: bool = True,
         num_rnn_layers: int = 1,
         rnn_hidden_size: int = 512,
         rnn_projection_size: int = 128,
@@ -50,6 +51,7 @@ class TextRNNTagger(DeepTagger):
             sequence_length=sequence_length,
             segmenter=segmenter,
             embedding_size=embedding_size,
+            use_batch_normalization=use_batch_normalization,
             text2vec=text2vec,
             algorithm="rnn",
             **kwargs
@@ -130,7 +132,9 @@ class TextRNNTagger(DeepTagger):
             epsilon=self.fc_epsilon,
             name="mlp",
         )(embeddings)
-        return CrfLossLayer(self.num_classes)([emissions, tag_ids], mask)
+        return CrfLossLayer(
+            self.num_classes, max_sequence_length=self.max_sequence_length
+        )([emissions, tag_ids], mask)
 
     @classmethod
     def _filter_config(cls, config: Dict[str, Any]) -> Dict[str, Any]:
